/*
 * SonarQube
 * Copyright (C) 2009-2017 SonarSource SA
 * mailto:info AT sonarsource DOT com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
package org.sonar.server.project.ws;

import org.sonar.api.server.ServerSide;
import org.sonar.api.server.ws.WebService;
import org.sonar.db.DbClient;
import org.sonar.db.DbSession;
import org.sonar.db.organization.OrganizationDto;
import org.sonar.server.organization.BillingValidations;
import org.sonar.server.organization.BillingValidationsProxy;

import static org.sonar.server.ws.WsUtils.checkFoundWithOptional;

@ServerSide
public class ProjectsWsSupport {
  public static final String PARAM_ORGANIZATION = "organization";

  private final DbClient dbClient;

  private final BillingValidationsProxy billingValidations;

  public ProjectsWsSupport(DbClient dbClient, BillingValidationsProxy billingValidations) {
    this.dbClient = dbClient;
    this.billingValidations = billingValidations;
  }

  void addOrganizationParam(WebService.NewAction action) {
    action.createParam(PARAM_ORGANIZATION)
      .setDescription("The key of the organization")
      .setRequired(false)
      .setInternal(true)
      .setSince("6.3");
  }

  OrganizationDto getOrganization(DbSession dbSession, String organizationKey) {
    return checkFoundWithOptional(
        dbClient.organizationDao().selectByKey(dbSession, organizationKey),
        "No organization for key '%s'", organizationKey);
  }

  void checkCanUpdateProjectsVisibility(OrganizationDto organization, boolean newProjectsPrivate) {
    try {
      billingValidations.checkCanUpdateProjectVisibility(new BillingValidations.Organization(organization.getKey(), organization.getUuid()), newProjectsPrivate);
    } catch (BillingValidations.BillingValidationsException e) {
      throw new IllegalArgumentException(e.getMessage());
    }
  }
}
